@@ -88,6 +88,7 @@ class FileHandler(object):
     __header = 0
     __streams = list()
     __df = DataFrame()
+    __fmtparams = dict()
 
     def __init__(self, file_path=None, file_dir=None, file_name=None, flag_read_only=False, sheet_names=None, header=0,
                  names=None, index_col=None, usecols=None, squeeze=False, dtype=None, true_values=None,
@@ -95,7 +96,7 @@ class FileHandler(object):
                  date_parser=None, thousands=None, comment=None, skipfooter=0, convert_float=True, dialect=None,
                  mangle_dupe_cols=True, xmlns_rs=None, dict_var=None, df=None, mode='a', timeout=DEFAULT_TIMEOUT,
                  check_interval=DEFAULT_CHECK_INTERVAL, fail_when_locked=DEFAULT_FAIL_WHEN_LOCKED, flags=LOCK_METHOD,
-                 truncate=False, **kwargs):
+                 truncate=False, fmtparams=None, **kwargs):
         self.file_path = file_path
         self.file_dir = file_dir
         self.file_name = file_name
@@ -131,6 +132,21 @@ class FileHandler(object):
         self.dialect = dialect
         self.truncate = truncate
         self.kwargs = kwargs
+        self.fmtparams = fmtparams
+
+    @property
+    def fmtparams(self):
+        return self.__fmtparams
+
+    @fmtparams.setter
+    def fmtparams(self, fmtparams):
+        if fmtparams:
+            if not isinstance(fmtparams, dict):
+                raise ValueError("'fmtparams' %r is not an instance of dict" % fmtparams)
+
+            self.__fmtparams = fmtparams
+        else:
+            self.__fmtparams = dict()
 
     @property
     def file_path(self):
@@ -453,7 +469,7 @@ class FileParser(object):
         self.reader.streams = self.__streams['open'] + self.__streams['default']
         return self.reader.parse()
 
-    def parse_csv(self, file_path, dialect=None, truncate=False, **kwargs):
+    def parse_csv(self, file_path, dialect=None, truncate=False, fmtparams=None, **kwargs):
         """
         Parses CSV data into data
 
@@ -464,7 +480,8 @@ class FileParser(object):
         :return: data
         """
 
-        self.reader = self.__engines['csv'](file_path=file_path, dialect=dialect, truncate=truncate, **kwargs)
+        self.reader = self.__engines['csv'](file_path=file_path, dialect=dialect, truncate=truncate,
+                                            fmtparams=fmtparams, **kwargs)
         self.reader.streams = self.__streams['csv'] + self.__streams['default']
         return self.reader.parse()
 
