@@ -5,6 +5,8 @@ from os.path import exists, join
 from datetime import datetime
 from portalocker import Lock
 from xml.sax.saxutils import escape
+from gc import collect
+from copy import deepcopy
 
 
 class XMLReader(FileHandler):
@@ -22,19 +24,22 @@ class XMLReader(FileHandler):
         from ..filehandler import is_an_xml
 
         if is_an_xml(self.file_path):
-            tree = xml_parse(self.file_path)
-            root = tree.getroot()
-            xml_objs = root.findall(self.xmlns_rs)
+            try:
+                tree = xml_parse(self.file_path)
+                root = tree.getroot()
+                xml_objs = root.findall(self.xmlns_rs)
 
-            if isinstance(self.dict_var, dict):
-                for item in xml_objs:
-                    self.dict_var = self.__parse_element(item, self.dict_var)
+                if isinstance(self.dict_var, dict):
+                    for item in xml_objs:
+                        self.dict_var = self.__parse_element(item, self.dict_var)
 
-                return self.dict_var
-            elif handler:
-                self.__parse_xml_root(xml_objs, handler, buffer)
-            else:
-                return self.__parse_xml_root(xml_objs, handler, buffer)
+                    return self.dict_var
+                elif handler:
+                    self.__parse_xml_root(xml_objs, handler, buffer)
+                else:
+                    return self.__parse_xml_root(xml_objs, handler, buffer)
+            finally:
+                collect()
 
     def __parse_xml_root(self, xml_objs, handler=None, buffer=None):
         xml_dicts = list()
@@ -44,15 +49,16 @@ class XMLReader(FileHandler):
             xml_dicts.append(self.__parse_element(xml_obj))
 
             if handler and buffer <= len(xml_dicts):
-                handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1, row_num,
-                        **self.kwargs)
+                handler(deepcopy(self.file_path), deepcopy(self.__parse_df(xml_dicts)),
+                        deepcopy(row_num - len(xml_dicts) + 1), deepcopy(row_num), **self.kwargs)
                 xml_dicts.clear()
 
             row_num += 1
 
         if handler:
             row_num -= 1
-            handler(self.file_path, self.__parse_df(xml_dicts), row_num - len(xml_dicts) + 1, row_num, **self.kwargs)
+            handler(deepcopy(self.file_path), deepcopy(self.__parse_df(xml_dicts)),
+                    deepcopy(row_num - len(xml_dicts) + 1), deepcopy(row_num), **self.kwargs)
         else:
             return self.__parse_df(xml_dicts)
 
